@@ -289,7 +289,7 @@ class VLASSDownloader(FileDownloader):
         '''
 
         # Obtain the HTML for the given tile
-        if '2.1' in epoch:
+        if '1.' not in epoch:
             self.logger.info(f'Downloading from https://archive-new.nrao.edu/vlass/quicklook/{epoch}/{tilename}')
             urlpath = urlopen(f"https://archive-new.nrao.edu/vlass/quicklook/{epoch}/{tilename}")
         else:
@@ -422,7 +422,7 @@ class VLASSDownloader(FileDownloader):
 
         imname = f"{subtile[:-1]}.I.iter1.image.pbcor.tt0.subim.fits"
         if len(glob.glob(imname)) == 0:
-            if '2.1' in epoch:
+            if '1.' not in epoch:
                 url_get = f"https://archive-new.nrao.edu/vlass/quicklook/{epoch}/{tilename}/{subtile}"
             else:
                 url_get = f"https://archive-new.nrao.edu/vlass/quicklook/{epoch}v2/{tilename}/{subtile}"
@@ -430,7 +430,7 @@ class VLASSDownloader(FileDownloader):
             self.logger.info('Downloading to ' + ddir)
             self.download_file(fname, target_dir=ddir)
             if consider_QA_rejected:
-                if '2.1' in epoch:
+                if '1.' not in epoch:
                     url_get = f"https://archive-new.nrao.edu/vlass/quicklook/{epoch}/QA_REJECTED/{subtile}"
                 else:
                     url_get = f"https://archive-new.nrao.edu/vlass/quicklook/{epoch}v2/QA_REJECTED/{subtile}"
@@ -525,11 +525,10 @@ class HiPSDownloader():
         else:
             self.hips = hips
         if not name:
-            self.name = self.hips
-            self.logger = logging.getLogger('EveryStamp:VODownloader')
+            self.name = self.hips.replace('/', '_')
         else:
             self.name = name
-            self.logger = logging.getLogger('EveryStamp:HiPSDownloader[{:s}]'.format(self.name))
+        self.logger = logging.getLogger('EveryStamp:HiPSDownloader[{:s}]'.format(self.name))
 
     def download(self, ra=0.0, dec=0.0, size=0.1, ddir=os.getcwd(), pixsize=1.0, mode='jpg'):
         ''' Download a cutout from the VLASS survey.
@@ -551,6 +550,9 @@ class HiPSDownloader():
         '''
         imsize = int(size / (pixsize / 3600))
         img = hips2fits.query(hips=self.hips, format=mode, width=imsize, height=imsize, projection='SIN', fov=size*u.deg, ra=ra*u.deg, dec=dec*u.deg)
+        if not os.path.exists(ddir):
+            self.logger.info('Download directory does not exist, creating it')
+            os.mkdir(ddir)
         if mode == 'jpg':
             from PIL import Image
             imdata = Image.fromarray(img)
