@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 ''' Python library aiming to provide a wrapper around various astronomical surveys that offer cutouts.'''
-__version__ = '1.1.0'
+__version__ = '1.2.0'
 __author__ = 'Frits Sweijen'
 __license__ = 'GPLv3'
 from typing import Generator
@@ -9,10 +9,13 @@ import argparse
 import logging
 logging.basicConfig(format='[%(name)s] %(asctime)s - %(levelname)s: %(message)s', level=logging.INFO)
 logger = logging.getLogger('EveryStamp')
+import os
 import shutil
 
 from astroquery.skyview import SkyView #type: ignore
 from collections.abc import Iterable
+import astropy.visualization
+import cv2 #type: ignore
 import requests
 
 # Check if LuminanceHDR is installed.
@@ -58,7 +61,7 @@ def _add_args_download(parser):
     required_args.add_argument('--mode', type=str, required=True, default='jpeg', choices=['jpeg', 'fits', 'both'], help='Image type to retrieve. Can be "jpeg", "fits" or "both" to retrieve either a JPEG image, FITS file or both. Default value is jpeg.')
 
     optional_args = parser.add_argument_group('Optional arguments')
-    optional_args.add_argument('--download_dir', type=str, required=False, default='', dest='ddir', help='Directory to store downloaded files. If not given will download to $PWD.')
+    optional_args.add_argument('--download_dir', type=str, required=False, default=os.getcwd(), dest='ddir', help='Directory to store downloaded files. If not given will download to $PWD.')
     optional_args.add_argument('--size', type=float, required=False, default=0.01, help='Cutout size in degrees.')
 
     legacy_args = parser.add_argument_group('[DESI Legacy Imaging Surveys]')
@@ -95,6 +98,7 @@ def _add_args_plot(parser):
     required_args.add_argument('--CLAHE', action='store_true', default=False, required=False, help='Apply contrast-limited adaptive histogram equalisation.')
     required_args.add_argument('--CLAHE-gridsize', default=5, type=int, required=False, help='Grid size to use for CLAHE.')
     required_args.add_argument('--CLAHE-cliplim', default=1.0, type=float, required=False, help='Clip limit to use for CLAHE.')
+    required_args.add_argument('--stretch', default=None, type=str, required=False, choices=['log', 'sqrt', 'squared', 'asinh', 'sinh'], help='Stretch an image with a certian function.')
 
     if HAS_LHDR:
         required_args.add_argument('--hdr-tonemap', default=None, type=str, choices=['ashikmin', 'drago', 'duran', 'fattal', 'ferradans', 'ferwerda', 'kimkautz', 'lischinski', 'mantiuk06', 'mantiuk08', 'pattanaik', 'reinhard02', 'reinhard05', 'vanhateren'], required=False, help='HDR tonemapping to apply')
@@ -178,6 +182,9 @@ def _process_args_download(args):
         parser : ArgumentParser
             ArgumentParser instance to which to add entries.
     '''
+    if args.ddir and (not os.path.exists(args.ddir)):
+        logger.info('Download directory does not exist, creating it')
+        os.mkdir(args.ddir)
     logger.info('Survey is %s', args.survey)
     if args.survey == 'legacy':
         from everystamp.downloaders import LegacyDownloader
@@ -234,12 +241,16 @@ def _process_args_plot(args):
             ArgumentParser instance to which to add entries.
     '''
     logger.info('Plotting image %s', args.image)
-    from everystamp.plotters import BasicPlot
+    from everystamp.plotters import BasicFITSPlot, BasicImagePlot
     from everystamp.tonemapping import gamma, make_nonnegative
     import numpy as np
     from everystamp.tonemapping.lhdr import ashikmin, drago, duran, fattal, ferradans, ferwerda, kimkautz, lischinski, mantiuk06, mantiuk08, reinhard02, reinhard05, pattanaik, vanhateren
-    bp = BasicPlot(args.image)
-    if HAS_LHDR:
+    if args.image.lower().endswith('fits'):
+        bp = BasicFITSPlot(args.image)
+    else:
+        # Probably an image format.
+        bp = BasicImagePlot(args.image)
+    if HAS_LHDR and args.hdr_tonemap:
         if args.hdr_tonemap == 'ashikmin':
             logger.info('Tonemapping image with ashikmin')
             bp.data = ashikmin(bp.data, eq2=args.ashikmin_eq2, simple=args.ashikmin_simple, local_threshold=args.ashikmin_local_threshol)
@@ -282,19 +293,55 @@ def _process_args_plot(args):
         if args.hdr_tonemap == 'vanhateren':
             logger.info('Tonemapping with vanhateren')
             bp.data = vanhateren(bp.data, pupil_area=args.vanhateren_pupil_area)
+    
     if args.CLAHE:
-        import cv2 #type: ignore
-        bp.data = make_nonnegative(bp.fitsdata)
-        bp.data /= np.nanmax(bp.data)
-        bp.data *= 2**16
-        bp.data = bp.data.astype(np.uint16)
-        clahe = cv2.createCLAHE(clipLimit=args.CLAHE_cliplim, tileGridSize=(args.CLAHE_gridsize, args.CLAHE_gridsize))
-        bp.data = clahe.apply(bp.data)
-    if args.gamma:
-        bp.data = gamma(bp.data, args.gamma)
-    bp.savedata(args.image.replace('.fits', '.tonemapped.fits'))
+        if args.image.lower().endswith('fits'):
+            bp.data = make_nonnegative(bp.fitsdata)
+            bp.data /= np.nanmax(bp.data)
+            bp.data *= 2**16
+            bp.data = bp.data.astype(np.uint16)
+            clahe = cv2.createCLAHE(clipLimit=args.CLAHE_cliplim, tileGridSize=(args.CLAHE_gridsize, args.CLAHE_gridsize))
+            bp.data = clahe.apply(bp.data)
+        else:
+            clahe = cv2.createCLAHE(clipLimit=args.CLAHE_cliplim, tileGridSize=(args.CLAHE_gridsize, args.CLAHE_gridsize))
+            Lab = cv2.cvtColor(bp.data, cv2.COLOR_RGB2Lab)
+            L, a, b = cv2.split(Lab)
+            L_clahe = clahe.apply(L)
+            Lab_clahe = cv2.merge((L_clahe, a, b))
+            cv2.cvtColor(Lab_clahe, cv2.COLOR_Lab2RGB)
+
+    if args.gamma != 1:
+        logger.info('Applying gamma stretch of {:f}'.format(args.gamma))
+        if args.image.lower().endswith('fits'):
+            bp.data = gamma(bp.data / np.nanmax(bp.data), args.gamma)
+        else:
+            Lab = cv2.cvtColor(bp.data.astype(np.uint8), cv2.COLOR_RGB2Lab)
+            L, a, b = cv2.split(Lab)
+            lookUpTable = np.empty((1,256), np.uint8)
+            for i in range(256):
+                lookUpTable[0,i] = np.clip(pow(i / 255.0, args.gamma) * 255.0, 0, 255)
+            L_gamma = cv2.LUT(L, lookUpTable)
+            Lab_gamma = cv2.merge((L_gamma, a, b))
+            bp.data = cv2.cvtColor(Lab_gamma, cv2.COLOR_Lab2RGB)
+    
+    if args.stretch:
+        # 'log10', 'sqrt', 'squared', 'asinh', 'sinh'
+        if args.stretch == 'log':
+            stretch = astropy.visualization.LogStretch()
+        elif args.stretch == 'sqrt':
+            stretch = astropy.visualization.SqrtStretch()
+        elif args.stretch == 'squared':
+            stretch = astropy.visualization.SquaredStretch()
+        elif args.stretch == 'asinh':
+            stretch = astropy.visualization.AsinhStretch()
+        elif args.stretch == 'sinh':
+            stretch = astropy.visualization.SinhStretch()
+        bp.data = stretch(bp.data / np.nanmax(bp.data), min)
+    
+    if args.image.lower().endswith('fits'):
+        bp.savedata(args.image.replace('.fits', '.tonemapped.fits'))
+        bp.plot_noaxes()
     bp.plot2D()
-    bp.plot_noaxes()
 
 
 def main():
