@@ -5,6 +5,7 @@ import os
 import subprocess
 
 from astropy.io import fits
+from PIL import Image
 from skimage import io
 import numpy
 
@@ -47,10 +48,11 @@ def _load_tonemapped_tmpdata(name: str, as_gray: bool = True) -> numpy.ndarray:
         data : numpy.ndarray
             NumPy array containing the image.
     '''
-    return io.imread(name, as_gray=as_gray)
+    return io.imread(name)
+    # return io.imread(name, as_gray=as_gray)
 
 
-def _store_tmpfile(data: numpy.ndarray, name: str) -> str:
+def _store_tmpfile(data: numpy.ndarray, name: str, header=None) -> str:
     ''' Store the data to tonemap to a temporary FITS file to pass to LuminanceHDR.
     
     Args:
@@ -61,8 +63,11 @@ def _store_tmpfile(data: numpy.ndarray, name: str) -> str:
         path : str
             Absolute path to the temporary file.
     '''
-    fits.writeto(data=data, filename=name, overwrite=True)
-    #img.save(name, compression=None, x_resolution=data.shape[0], y_resolution=data.shape[1])
+    if name.lower().endswith('fits'):
+        fits.writeto(data=data, filename=name, header=header, overwrite=True)
+    else:
+        im = Image.fromarray(data)
+        im.convert(mode='RGB').save(name)
     return os.path.abspath(name)
 
 
@@ -85,8 +90,8 @@ def ashikmin(data, eq2: bool = True, simple: Optional[float] = None, local_thres
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_ashikmin.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_ashikmin.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo ashikmin '
     cmd += f'--tmoAshEq2 {eq2} '
     cmd += f'--tmoAshSimple {simple} '
@@ -115,8 +120,8 @@ def drago(data: numpy.ndarray, bias: float = 0.85) -> numpy.ndarray:
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_drago.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_drago.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo drago '
     if bias is not None:
         cmd += f'--tmoDrgBias {bias} '
@@ -147,8 +152,8 @@ def duran(data: numpy.ndarray, sigma_spatial: Optional[float] = None, sigma_rang
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_durand.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_durand.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo durand '
     if sigma_spatial is not None:
         cmd += f'--tmoDurSigmaS {sigma_spatial} '
@@ -185,8 +190,8 @@ def fattal(data: numpy.ndarray, alpha: Optional[float] = None, beta: Optional[fl
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_fattal.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_fattal.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo fattal '
     if alpha is not None:
         cmd += f'--tmoFatAlpha {alpha} '
@@ -221,8 +226,8 @@ def ferradans(data: numpy.ndarray, rho: float = -2, inv_alpha: float = 5) -> num
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_ferradans.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_ferradans.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo ferradans '
     if rho is not None:
         cmd += f'--tmoFerRho {rho} '
@@ -253,8 +258,8 @@ def ferwerda(data, multiplier: Optional[float] = None, luminance_adaptation: Opt
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_ferwerda.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_ferwerda.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo ferradans '
     if multiplier is not None:
         cmd += f'--tmoFerwerdaMul {multiplier} '
@@ -285,8 +290,8 @@ def kimkautz(data, c1: Optional[float] = None, c2: Optional[float] = None) -> nu
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_kimkautz.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_kimkautz.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo kimkautz '
     if c1 is not None:
         cmd += f'--tmoKimKautzC1 {c1} '
@@ -315,8 +320,8 @@ def lischinski(data, alpha: Optional[float] = None):
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_lischinski.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_lischinski.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo lischinski '
     if alpha is not None:
         cmd += f'--tmoLischinskiAlpha {alpha} '
@@ -349,8 +354,8 @@ def mantiuk06(data, contrast: Optional[float] = None, saturation: Optional[float
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_mantiuk06.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_mantiuk06.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo mantiuk06 '
     if contrast is not None:
         cmd += f'--tmoM06Contrast {contrast} '
@@ -388,8 +393,8 @@ def mantiuk08(data, contrast_enhancement: Optional[float] = None, colour_saturat
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_mantiuk08.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_mantiuk08.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo mantiuk08 '
     if colour_saturation is not None:
         cmd += f'--tmoM08ColorSaturation {colour_saturation} '
@@ -431,8 +436,8 @@ def reinhard02(data, key: Optional[float] = None, phi: Optional[float] = None, u
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_reinhard02.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_reinhard02.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo reinhard02 '
     if key is not None:
         cmd += f'--tmoR02Key {key} '
@@ -473,8 +478,8 @@ def reinhard05(data, brightness: Optional[float] = None, chroma: Optional[float]
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_reinhard05.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_reinhard05.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo reinhard05 '
     if brightness is not None:
         cmd += f'--tmoR05Brightness {brightness} '
@@ -513,8 +518,8 @@ def pattanaik(data, multiplier: Optional[float] = None, local_tonemap: bool = Tr
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_pattanaik.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_pattanaik.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo pattanaik '
     if multiplier is not None:
         cmd += f'--tmoPatMultiplier {multiplier} '
@@ -547,8 +552,8 @@ def vanhateren(data, pupil_area: Optional[float] = None):
         data_tm : numpy.ndarray
             Tonemapped data.
     '''
-    tmpname = _store_tmpfile(data, 'tmp_vanhateren.fits')
-    tmpname_out = tmpname.replace('.fits', '.tonemapped.tiff')
+    tmpname = _store_tmpfile(data, 'tmp_vanhateren.tiff')
+    tmpname_out = tmpname.replace('.tiff', '.tonemapped.tiff')
     cmd = BASECOMMAND + ' -e 0 --tmo vanhateren '
     if pupil_area is not None:
         cmd += f'--tmoVanHaterenPupilArea {pupil_area} '
